@@ -102,7 +102,7 @@ class gram():
     def __gt__(self, other):
         return gram(f"({self.value})/({other.rule()})")
 
-    def _floordiv__(self, other):
+    def __floordiv__(self, other):
         return gram(f"({self.value})/({other.rule()})")
 
     def __lt__(self, other):
@@ -114,6 +114,9 @@ class gram():
         else:
             return gram(f"{self.value}, |({other.rule()})")
 
+    def __rmul__(self, other):
+        return gram(f"{self.value}\?({other.rule()})")
+
     def __getitem__(self, key):
         rule = key.rule()
         case_content = ""
